==> gitlab-18.8.4-1-x86_64.pkg.tar.zst: usr/share/webapps/gitlab/doc/user/application_security/continuous_vulnerability_scanning/_index.md <==
---
stage: Application Security Testing
group: Composition Analysis
info: To determine the technical writer assigned to the Stage/Group associated with this page, see https://handbook.gitlab.com/handbook/product/ux/technical-writing/#assignments
title: Continuous vulnerability scanning
description: Scanning, dependencies, advisories, and background jobs.
---

{{< details >}}

- Tier: Ultimate
- Offering: GitLab.com, GitLab Self-Managed, GitLab Dedicated

{{< /details >}}

{{< history >}}

- Continuous dependency scanning [introduced](https://gitlab.com/gitlab-org/gitlab/-/issues/371063) with [feature flags](../../../administration/feature_flags/_index.md) `dependency_scanning_on_advisory_ingestion` and `package_metadata_advisory_scans` enabled by default.
- [Generally available](https://gitlab.com/gitlab-org/gitlab/-/issues/425753) in GitLab 16.10. Feature flags `dependency_scanning_on_advisory_ingestion` and `package_metadata_advisory_scans` removed.
- Continuous container scanning [introduced](https://gitlab.com/gitlab-org/gitlab/-/issues/435435) in GitLab 16.8 [with a flag](../../../administration/feature_flags/_index.md) named `container_scanning_continuous_vulnerability_scans`. Disabled by default.
- Continuous container scanning [enabled on GitLab Self-Managed, and GitLab Dedicated](https://gitlab.com/gitlab-org/gitlab/-/issues/437162) in GitLab 16.10.
- [Generally available](https://gitlab.com/gitlab-org/gitlab/-/issues/443712) in GitLab 17.0. Feature flag `container_scanning_continuous_vulnerability_scans` removed.
- CVS triggering on new components, for container scanning and dependency scanning, [introduced](https://gitlab.com/gitlab-org/gitlab/-/issues/464575) in GitLab 17.3 [with a flag](../../../administration/feature_flags/_index.md) named `dependency_scanning_using_sbom_reports`. Disabled by default.
- CVS triggering on new components, for container scanning, [introduced](https://gitlab.com/gitlab-org/gitlab/-/merge_requests/165368) in GitLab 17.4 [with a flag](../../../administration/feature_flags/_index.md) named `cvs_for_container_scanning`. Disabled by default.
- CVS triggering on new components, for dependency scanning only, [enabled on GitLab Self-Managed, and GitLab Dedicated](https://gitlab.com/gitlab-org/gitlab/-/issues/395692) in 17.5.
- Feature flag `dependency_scanning_using_sbom_reports` removed in GitLab 17.10.

{{< /history >}}

Continuous vulnerability scanning looks for security vulnerabilities in your project's dependencies by comparing their component names and versions against information in the latest [security advisories](#security-advisories).

[New vulnerabilities may arise](#checking-new-vulnerabilities) when continuous vulnerability scanning triggers scans on all projects that contain components with [supported package types](#supported-package-types).

Vulnerabilities created by continuous vulnerability scanning use `GitLab SBoM Vulnerability Scanner` as the scanner name.

In contrast to CI-based security scans, continuous vulnerability scanning is executed through background jobs (Sidekiq) rather than CI pipelines and no Security report artifacts are generated.

## Prerequisites

- A project with dependencies [supported](#supported-package-types) by continuous vulnerability scanning. See [how to generate a CycloneDX SBOM report](#how-to-generate-a-cyclonedx-sbom-report).
- [Security advisories](#security-advisories) synchronized to the GitLab instance.

## Supported package types

Continuous vulnerability scanning supports components with the following [PURL types](https://github.com/package-url/purl-spec/blob/346589846130317464b677bc4eab30bf5040183a/PURL-TYPES.rst):

- `apk`
- `cargo`
- `conan`
- `deb`
- `go`
- `maven`
- `npm`
- `nuget`
- `packagist`
- `pub`
- `pypi`
- `rpm`
- `rubygem`
- `swift`

Go pseudo versions are not supported. A project dependency that references a Go pseudo version is
never considered as affected because this might result in false negatives.

RPM versions containing `^` are not supported. Work to support these versions is tracked in [issue 459969](https://gitlab.com/gitlab-org/gitlab/-/issues/459969).
APK versions containing leading zeros are not supported. Work to support these versions is tracked in [issue 471509](https://gitlab.com/gitlab-org/gitlab/-/issues/471509).

RPM packages in Red Hat distributions are not supported. Work to support this use case is tracked in [epic 12980](https://gitlab.com/groups/gitlab-org/-/epics/12980).

## How to generate a CycloneDX SBOM report

Use a [CycloneDX SBOM report](../../../ci/yaml/artifacts_reports.md#artifactsreportscyclonedx) to register your project components with GitLab.

GitLab offers security analyzers that can generate a report compatible with GitLab:

- [Container scanning](../container_scanning/_index.md#getting-started)
- [Container scanning for registry](../container_scanning/_index.md#container-scanning-for-registry)
- [Dependency scanning](../dependency_scanning/_index.md#getting-started)
- [Dependency scanning CI/CD component](https://gitlab.com/explore/catalog/components/dependency-scanning) (experimental)

## Checking new vulnerabilities

New vulnerabilities detected by continuous vulnerability scanning are visible on the [vulnerability report](../vulnerability_report/_index.md).
However, they are not listed in the pipeline where the affected SBOM component was detected.

Vulnerabilities are created according to the following scenarios:

- After a [security advisory](#security-advisories) is added or updated, it may take a few hours for the corresponding vulnerabilities
  to be added to your projects, provided the codebase remains unchanged. Only advisories published within the last 14 days
  are considered for continuous vulnerability scanning.

- For existing [security advisories](#security-advisories), a vulnerability is **only** created if a new component is detected and either of the following conditions are true:

  - The component is listed in a CycloneDX SBOM generated by [dependency scanning](../dependency_scanning/_index.md#cyclonedx-software-bill-of-materials).
  - The [feature flag](../../../administration/feature_flags/_index.md) `cvs_for_container_scanning` is enabled, and the component is listed in a CycloneDX SBOM generated by [container scanning](../container_scanning/_index.md#cyclonedx-software-bill-of-materials).

## When vulnerabilities are no longer detected

Continuous vulnerability scanning automatically creates vulnerabilities when a new advisory is published
but it is not able to tell when a vulnerability is no longer present in the project. To do so, GitLab
still requires to have a [container scanning](../container_scanning/_index.md) or a
[dependency scanning](../dependency_scanning/_index.md) scan executed in a pipeline for the default branch,
and a corresponding security report artifact generated with the up to date information. When these reports
are processed, and when they no longer contain some vulnerabilities, these are flagged as such even if
they were created by continuous vulnerability scanning. This behavior has been introduced in 17.1 with
[issue 441490](https://gitlab.com/gitlab-org/gitlab/-/issues/441490) and applies to scanners maintained
by GitLab (`Trivy`, `gemnasium`, `gemnasium-python`, `gemnasium-maven`).

{{< alert type="warning" >}}

Vulnerabilities detected through container scanning for registry cannot be resolved using this
method and remain visible even after you fix them in your images. This occurs because Container
Scanning for Registry generates only SBOMs, not the security reports required to mark
vulnerabilities as resolved.

{{< /alert >}}

## Security advisories

Continuous vulnerability scanning uses the Package Metadata Database, a service managed by GitLab which aggregates license and security advisory data, and regularly publishes updates that are used by GitLab.com and GitLab Self-Managed instances.

On GitLab.com, the synchronization is managed by GitLab and is available to all projects.

On GitLab Self-Managed, you can [choose package registry metadata to synchronize](../../../administration/settings/security_and_compliance.md#choose-package-registry-metadata-to-sync) in the **Admin** area for the GitLab instance.

### Data sources

Current data sources for security advisories include:

- [GitLab advisory database](https://advisories.gitlab.com/)
- [Trivy DB](https://github.com/aquasecurity/trivy-db)

### Contributing to the vulnerability database

To find a vulnerability, you can search the [`GitLab advisory database`](https://advisories.gitlab.com/).
You can also [submit new vulnerabilities](https://gitlab.com/gitlab-org/security-products/gemnasium-db/blob/master/CONTRIBUTING.md).

==> gitlab-18.9.1-1-x86_64.pkg.tar.zst: usr/share/webapps/gitlab/doc/user/application_security/continuous_vulnerability_scanning/_index.md <==
---
stage: Application Security Testing
group: Composition Analysis
info: To determine the technical writer assigned to the Stage/Group associated with this page, see https://handbook.gitlab.com/handbook/product/ux/technical-writing/#assignments
title: Continuous vulnerability scanning
description: Scanning, dependencies, advisories, and background jobs.
---

{{< details >}}

- Tier: Ultimate
- Offering: GitLab.com, GitLab Self-Managed, GitLab Dedicated

{{< /details >}}

{{< history >}}

- Continuous dependency scanning [introduced](https://gitlab.com/gitlab-org/gitlab/-/issues/371063) with [feature flags](../../../administration/feature_flags/_index.md) `dependency_scanning_on_advisory_ingestion` and `package_metadata_advisory_scans` enabled by default.
- [Generally available](https://gitlab.com/gitlab-org/gitlab/-/issues/425753) in GitLab 16.10. Feature flags `dependency_scanning_on_advisory_ingestion` and `package_metadata_advisory_scans` removed.
- Continuous container scanning [introduced](https://gitlab.com/gitlab-org/gitlab/-/issues/435435) in GitLab 16.8 [with a flag](../../../administration/feature_flags/_index.md) named `container_scanning_continuous_vulnerability_scans`. Disabled by default.
- Continuous container scanning [enabled on GitLab Self-Managed, and GitLab Dedicated](https://gitlab.com/gitlab-org/gitlab/-/issues/437162) in GitLab 16.10.
- [Generally available](https://gitlab.com/gitlab-org/gitlab/-/issues/443712) in GitLab 17.0. Feature flag `container_scanning_continuous_vulnerability_scans` removed.
- CVS triggering on new components, for container scanning and dependency scanning, [introduced](https://gitlab.com/gitlab-org/gitlab/-/issues/464575) in GitLab 17.3 [with a flag](../../../administration/feature_flags/_index.md) named `dependency_scanning_using_sbom_reports`. Disabled by default.
- CVS triggering on new components, for container scanning, [introduced](https://gitlab.com/gitlab-org/gitlab/-/merge_requests/165368) in GitLab 17.4 [with a flag](../../../administration/feature_flags/_index.md) named `cvs_for_container_scanning`. Disabled by default.
- CVS triggering on new components, for dependency scanning only, [enabled on GitLab Self-Managed, and GitLab Dedicated](https://gitlab.com/gitlab-org/gitlab/-/issues/395692) in 17.5.
- Feature flag `dependency_scanning_using_sbom_reports` removed in GitLab 17.10.

{{< /history >}}

Continuous vulnerability scanning looks for security vulnerabilities in your project's dependencies by comparing their component names and versions against information in the latest [security advisories](#security-advisories).

[New vulnerabilities may arise](#checking-new-vulnerabilities) when continuous vulnerability scanning triggers scans on all projects that contain components with [supported package types](#supported-package-types).

Vulnerabilities created by continuous vulnerability scanning use `GitLab SBoM Vulnerability Scanner` as the scanner name.

In contrast to CI-based security scans, continuous vulnerability scanning is executed through background jobs (Sidekiq) rather than CI pipelines and no Security report artifacts are generated.

## Prerequisites

- A project with dependencies [supported](#supported-package-types) by continuous vulnerability scanning. See [how to generate a CycloneDX SBOM report](#how-to-generate-a-cyclonedx-sbom-report).
- [Security advisories](#security-advisories) synchronized to the GitLab instance.

## Supported package types

Continuous vulnerability scanning supports components with the following [PURL types](https://github.com/package-url/purl-spec/blob/346589846130317464b677bc4eab30bf5040183a/PURL-TYPES.rst):

- `apk`
- `cargo`
- `conan`
- `deb`
- `go`
- `maven`
- `npm`
- `nuget`
- `packagist`
- `pub`
- `pypi`
- `rpm`
- `rubygem`
- `swift`

Go pseudo versions are not supported. A project dependency that references a Go pseudo version is
never considered as affected because this might result in false negatives.

RPM versions containing `^` are not supported. Work to support these versions is tracked in [issue 459969](https://gitlab.com/gitlab-org/gitlab/-/issues/459969).
APK versions containing leading zeros are not supported. Work to support these versions is tracked in [issue 471509](https://gitlab.com/gitlab-org/gitlab/-/issues/471509).

RPM packages in Red Hat distributions are not supported. Work to support this use case is tracked in [epic 12980](https://gitlab.com/groups/gitlab-org/-/epics/12980).

## How to generate a CycloneDX SBOM report

Use a [CycloneDX SBOM report](../../../ci/yaml/artifacts_reports.md#artifactsreportscyclonedx) to register your project components with GitLab.

GitLab offers security analyzers that can generate a report compatible with GitLab:

- [Container scanning](../container_scanning/_index.md#getting-started)
- [Container scanning for registry](../container_scanning/_index.md#container-scanning-for-registry)
- [Dependency scanning](../dependency_scanning/_index.md#getting-started)
- [Dependency scanning CI/CD component](https://gitlab.com/explore/catalog/components/dependency-scanning) (experimental)

## Checking new vulnerabilities

New vulnerabilities detected by continuous vulnerability scanning are visible on the [vulnerability report](../vulnerability_report/_index.md).
However, they are not listed in the pipeline where the affected SBOM component was detected.

Vulnerabilities are created according to the following scenarios:

- After a [security advisory](#security-advisories) is added or updated, it may take a few hours for the corresponding vulnerabilities
  to be added to your projects, provided the codebase remains unchanged. Only advisories published within the last 14 days
  are considered for continuous vulnerability scanning.

- For existing [security advisories](#security-advisories), a vulnerability is **only** created if a new component is detected and either of the following conditions are true:

  - The component is listed in a CycloneDX SBOM generated by [dependency scanning](../dependency_scanning/_index.md#cyclonedx-software-bill-of-materials).
  - The [feature flag](../../../administration/feature_flags/_index.md) `cvs_for_container_scanning` is enabled, and the component is listed in a CycloneDX SBOM generated by [container scanning](../container_scanning/_index.md#cyclonedx-software-bill-of-materials).

## When vulnerabilities are no longer detected

Continuous vulnerability scanning automatically creates vulnerabilities when a new advisory is published
but it is not able to tell when a vulnerability is no longer present in the project. To do so, GitLab
still requires to have a [container scanning](../container_scanning/_index.md) or a
[dependency scanning](../dependency_scanning/_index.md) scan executed in a pipeline for the default branch,
and a corresponding security report artifact generated with the up to date information. When these reports
are processed, and when they no longer contain some vulnerabilities, these are flagged as such even if
they were created by continuous vulnerability scanning. This behavior has been introduced in 17.1 with
[issue 441490](https://gitlab.com/gitlab-org/gitlab/-/issues/441490) and applies to scanners maintained
by GitLab (`Trivy`, `gemnasium`, `gemnasium-python`, `gemnasium-maven`).

> [!warning]
> Vulnerabilities detected through container scanning for registry cannot be resolved using this
> method and remain visible even after you fix them in your images. This occurs because Container
> Scanning for Registry generates only SBOMs, not the security reports required to mark
> vulnerabilities as resolved.

## Security advisories

Continuous vulnerability scanning uses the Package Metadata Database, a service managed by GitLab which aggregates license and security advisory data, and regularly publishes updates that are used by GitLab.com and GitLab Self-Managed instances.

On GitLab.com, the synchronization is managed by GitLab and is available to all projects.

On GitLab Self-Managed, you can [choose package registry metadata to synchronize](../../../administration/settings/security_and_compliance.md#choose-package-registry-metadata-to-sync) in the **Admin** area for the GitLab instance.

### Data sources

Current data sources for security advisories include:

- [GitLab advisory database](https://advisories.gitlab.com/)
- [Trivy DB](https://github.com/aquasecurity/trivy-db)

### Contributing to the vulnerability database

To find a vulnerability, you can search the [`GitLab advisory database`](https://advisories.gitlab.com/).
You can also [submit new vulnerabilities](https://gitlab.com/gitlab-org/security-products/gemnasium-db/blob/master/CONTRIBUTING.md).
